fix IPCP length test to allow Terminate-Request (4 bytes)
authorBrendan O'Dea <bod@optus.net>
Mon, 27 Mar 2006 03:01:08 +0000 (03:01 +0000)
committerBrendan O'Dea <bod@optus.net>
Mon, 27 Mar 2006 03:01:08 +0000 (03:01 +0000)
Changes
l2tpns.h
l2tpns.spec
ppp.c

diff --git a/Changes b/Changes
index 75c50bf..bbb16bd 100644 (file)
--- a/Changes
+++ b/Changes
@@ -1,3 +1,6 @@
+* Mon Mar 27 2006 Brendan O'Dea <bod@optus.net> 2.1.17
+- Fix IPCP length test to allow Terminate-Request (4 bytes).
+
 * Thu Feb 23 2006 Brendan O'Dea <bod@optus.net> 2.1.16
 - Send configured magic-no in LCP EchoReq when LCP is opened.
 - Correct addition of single IP to pool (Jonathan Yarden).
index 0bc90ab..0fa5ac4 100644 (file)
diff --git a/ppp.c b/ppp.c
index 4fe4f6a..3584fe4 100644 (file)
--- a/ppp.c
+++ b/ppp.c
@@ -1,6 +1,6 @@
 // L2TPNS PPP Stuff
 
-char const *cvs_id_ppp = "$Id: ppp.c,v 1.96 2006-02-17 15:05:14 bodea Exp $";
+char const *cvs_id_ppp = "$Id: ppp.c,v 1.97 2006-03-27 03:01:08 bodea Exp $";
 
 #include <stdio.h>
 #include <string.h>
@@ -967,7 +967,7 @@ void processipcp(sessionidt s, tunnelidt t, uint8_t *p, uint16_t l)
        CSTAT(processipcp);
 
        LOG_HEX(5, "IPCP", p, l);
-       if (l < 5)
+       if (l < 4)
        {
                LOG(1, s, t, "Short IPCP %d bytes\n", l);
                STAT(tunnel_rx_errors);
--- a/l2tpns.h
+++ b/l2tpns.h
@@ -1,5 +1,5 @@
 // L2TPNS Global Stuff
-// $Id: l2tpns.h,v 1.109 2005-12-20 04:57:16 bodea Exp $
+// $Id: l2tpns.h,v 1.110 2006-03-27 03:01:08 bodea Exp $
 
 #ifndef __L2TPNS_H__
 #define __L2TPNS_H__
@@ -14,7 +14,7 @@
 #include <sys/types.h>
 #include <libcli.h>
 
-#define VERSION        "2.1.16"
+#define VERSION        "2.1.17"
 
 // Limits
 #define MAXTUNNEL      500             // could be up to 65535
index ec4d17c..8a56285 100644 (file)
@@ -1,6 +1,6 @@
 Summary: A high-speed clustered L2TP LNS
 Name: l2tpns
-Version: 2.1.16
+Version: 2.1.17
 Release: 1
 License: GPL
 Group: System Environment/Daemons
@@ -43,5 +43,5 @@ rm -rf %{buildroot}
 %attr(644,root,root) /usr/share/man/man[58]/*
 
 %changelog
-* Thu Feb 23 2006 Brendan O'Dea <bod@optus.net> 2.1.16-1
-- 2.1.16 release, see /usr/share/doc/l2tpns-2.1.16/Changes
+* Mon Mar 27 2006 Brendan O'Dea <bod@optus.net> 2.1.17-1
+- 2.1.17 release, see /usr/share/doc/l2tpns-2.1.17/Changes